@@ -30,7 +30,9 @@ function condition_operator2str($operator) {
 		CONDITION_OPERATOR_LESS_EQUAL => _('is less than or equals'),
 		CONDITION_OPERATOR_NOT_IN => _('not in'),
 		CONDITION_OPERATOR_YES => _('Yes'),
-		CONDITION_OPERATOR_NO => _('No')
+		CONDITION_OPERATOR_NO => _('No'),
+		CONDITION_OPERATOR_REGEXP => _('matches'),
+		CONDITION_OPERATOR_NOT_REGEXP => _('does not match')
 	];
 
 	return $operators[$operator];
@@ -510,7 +512,7 @@ function getActionOperationDescriptions(array $actions, $type) {
 
 	if ($media_typeids) {
 		$media_types = API::Mediatype()->get([
-			'output' => ['description'],
+			'output' => ['name'],
 			'mediatypeids' => $media_typeids,
 			'preservekeys' => true
 		]);
@@ -571,7 +573,7 @@ function getActionOperationDescriptions(array $actions, $type) {
 						$media_typeid = $operation['opmessage']['mediatypeid'];
 
 						if ($media_typeid != 0 && isset($media_types[$media_typeid])) {
-							$media_type = $media_types[$media_typeid]['description'];
+							$media_type = $media_types[$media_typeid]['name'];
 						}
 
 						if (array_key_exists('opmessage_usr', $operation) && $operation['opmessage_usr']) {
@@ -734,7 +736,7 @@ function getActionOperationDescriptions(array $actions, $type) {
 						$media_typeid = $operation['opmessage']['mediatypeid'];
 
 						if ($media_typeid != 0 && isset($media_types[$media_typeid])) {
-							$media_type = $media_types[$media_typeid]['description'];
+							$media_type = $media_types[$media_typeid]['name'];
 						}
 
 						if (array_key_exists('opmessage_usr', $operation) && $operation['opmessage_usr']) {
@@ -983,41 +985,41 @@ function getActionOperationHints(array $operations, array $defaultMessage) {
  */
 function get_conditions_by_eventsource($eventsource) {
 	$conditions[EVENT_SOURCE_TRIGGERS] = [
-		CONDITION_TYPE_APPLICATION,
-		CONDITION_TYPE_HOST_GROUP,
-		CONDITION_TYPE_TEMPLATE,
-		CONDITION_TYPE_HOST,
-		CONDITION_TYPE_TRIGGER,
 		CONDITION_TYPE_TRIGGER_NAME,
+		CONDITION_TYPE_TRIGGER,
 		CONDITION_TYPE_TRIGGER_SEVERITY,
-		CONDITION_TYPE_TIME_PERIOD,
+		CONDITION_TYPE_APPLICATION,
+		CONDITION_TYPE_HOST,
+		CONDITION_TYPE_HOST_GROUP,
 		CONDITION_TYPE_SUPPRESSED,
 		CONDITION_TYPE_EVENT_TAG,
-		CONDITION_TYPE_EVENT_TAG_VALUE
+		CONDITION_TYPE_EVENT_TAG_VALUE,
+		CONDITION_TYPE_TEMPLATE,
+		CONDITION_TYPE_TIME_PERIOD
 	];
 	$conditions[EVENT_SOURCE_DISCOVERY] = [
 		CONDITION_TYPE_DHOST_IP,
-		CONDITION_TYPE_DSERVICE_TYPE,
-		CONDITION_TYPE_DSERVICE_PORT,
-		CONDITION_TYPE_DRULE,
 		CONDITION_TYPE_DCHECK,
 		CONDITION_TYPE_DOBJECT,
+		CONDITION_TYPE_DRULE,
 		CONDITION_TYPE_DSTATUS,
-		CONDITION_TYPE_DUPTIME,
+		CONDITION_TYPE_PROXY,
 		CONDITION_TYPE_DVALUE,
-		CONDITION_TYPE_PROXY
+		CONDITION_TYPE_DSERVICE_PORT,
+		CONDITION_TYPE_DSERVICE_TYPE,
+		CONDITION_TYPE_DUPTIME
 	];
 	$conditions[EVENT_SOURCE_AUTO_REGISTRATION] = [
 		CONDITION_TYPE_HOST_NAME,
-		CONDITION_TYPE_PROXY,
-		CONDITION_TYPE_HOST_METADATA
+		CONDITION_TYPE_HOST_METADATA,
+		CONDITION_TYPE_PROXY
 	];
 	$conditions[EVENT_SOURCE_INTERNAL] = [
 		CONDITION_TYPE_APPLICATION,
 		CONDITION_TYPE_EVENT_TYPE,
+		CONDITION_TYPE_HOST,
 		CONDITION_TYPE_HOST_GROUP,
-		CONDITION_TYPE_TEMPLATE,
-		CONDITION_TYPE_HOST
+		CONDITION_TYPE_TEMPLATE
 	];
 
 	if (isset($conditions[$eventsource])) {
@@ -1266,14 +1268,18 @@ function get_operators_by_conditiontype($conditiontype) {
 	];
 	$operators[CONDITION_TYPE_HOST_NAME] = [
 		CONDITION_OPERATOR_LIKE,
-		CONDITION_OPERATOR_NOT_LIKE
+		CONDITION_OPERATOR_NOT_LIKE,
+		CONDITION_OPERATOR_REGEXP,
+		CONDITION_OPERATOR_NOT_REGEXP
 	];
 	$operators[CONDITION_TYPE_EVENT_TYPE] = [
 		CONDITION_OPERATOR_EQUAL
 	];
 	$operators[CONDITION_TYPE_HOST_METADATA] = [
 		CONDITION_OPERATOR_LIKE,
-		CONDITION_OPERATOR_NOT_LIKE
+		CONDITION_OPERATOR_NOT_LIKE,
+		CONDITION_OPERATOR_REGEXP,
+		CONDITION_OPERATOR_NOT_REGEXP
 	];
 	$operators[CONDITION_TYPE_EVENT_TAG] = [
 		CONDITION_OPERATOR_EQUAL,
@@ -1727,7 +1733,7 @@ function getEventUpdates(array $event) {
  * @param array  $actions['messages']    Messages icon data.
  * @param array  $actions['severities']  Severity change icon data.
  * @param array  $actions['actions']     Actions icon data.
- * @param array  $mediatypes             Mediatypes with maxattempts value and description.
+ * @param array  $mediatypes             Mediatypes with maxattempts value and name.
  * @param array  $users                  User name, surname and alias.
  * @param array  $config                 Zabbix config.
  *
@@ -1888,8 +1894,8 @@ function makeEventSeverityChangesIcon(array $data, array $users, array $config)
  * @param bool   $data['has_uncomplete_action']     Does the event have at least one uncompleted alert action.
  * @param bool   $data['has_failed_action']         Does the event have at least one failed alert action.
  * @param array  $users                             User name, surname and alias.
- * @param array  $mediatypes                        Mediatypes with maxattempts value and description.
- * @param string $mediatypes[]['description']       Mediatype description.
+ * @param array  $mediatypes                        Mediatypes with maxattempts value and name.
+ * @param string $mediatypes[]['name']              Mediatype name.
  * @param array  $config                            Zabbix config.
  *
  * @return CSpan|null
@@ -1918,7 +1924,7 @@ function makeEventActionsIcon(array $data, array $users, array $mediatypes, arra
 			}
 			elseif ($action['alerttype'] == ALERT_TYPE_MESSAGE) {
 				$message = array_key_exists($action['mediatypeid'], $mediatypes)
-					? $mediatypes[$action['mediatypeid']]['description']
+					? $mediatypes[$action['mediatypeid']]['name']
 					: '';
 			}
 		}
@@ -2228,8 +2234,9 @@ function makeActionTableInfo(array $action, array $mediatypes) {
 		if ($action['alerttype'] == ALERT_TYPE_MESSAGE
 				&& ($action['status'] == ALERT_STATUS_NEW || $action['status'] == ALERT_STATUS_NOT_SENT)) {
 			$info_icons[] = makeWarningIcon(array_key_exists($action['mediatypeid'], $mediatypes)
-				? _n(_('%1$s retry left'), _('%1$s retries left'),
-						$mediatypes[$action['mediatypeid']]['maxattempts'] - $action['retries'])
+				? _n('%1$s retry left', '%1$s retries left',
+						$mediatypes[$action['mediatypeid']]['maxattempts'] - $action['retries']
+				)
 				: ''
 			);
 		}
