@@ -19,17 +19,18 @@
 
 
 jQuery(function($) {
-	var KEY = {
-		ARROW_DOWN: 40,
-		ARROW_LEFT: 37,
-		ARROW_RIGHT: 39,
-		ARROW_UP: 38,
-		BACKSPACE: 8,
-		DELETE: 46,
-		ENTER: 13,
-		ESCAPE: 27,
-		TAB: 9
-	};
+	var ZBX_STYLE_CLASS = 'multiselect-control',
+		KEY = {
+			ARROW_DOWN: 40,
+			ARROW_LEFT: 37,
+			ARROW_RIGHT: 39,
+			ARROW_UP: 38,
+			BACKSPACE: 8,
+			DELETE: 46,
+			ENTER: 13,
+			ESCAPE: 27,
+			TAB: 9
+		};
 
 	/**
 	 * Multi select helper.
@@ -78,9 +79,9 @@ jQuery(function($) {
 		 * @return array    array of multiselect value objects
 		 */
 		getData: function() {
-			var ms = this.first().data('multiSelect');
+			var ms = this.first().data('multiSelect'),
+				data = [];
 
-			var data = [];
 			for (var id in ms.values.selected) {
 				var item = ms.values.selected[id];
 
@@ -101,34 +102,39 @@ jQuery(function($) {
 		 */
 		resize: function() {
 			return this.each(function() {
-				var obj = $(this);
-				var ms = $(this).data('multiSelect');
+				var $obj = $(this),
+					ms = $obj.data('multiSelect');
 
-				resizeAllSelectedTexts(obj, ms.options, ms.values);
+				resizeAllSelectedTexts($obj, ms.options, ms.values);
 			});
 		},
 
 		/**
 		 * Insert outside data
 		 *
-		 * @param object    multiselect value object
+		 * @param array    array of multiselect value objects
 		 *
 		 * @return jQuery
 		 */
-		addData: function(item) {
+		addData: function(items) {
 			return this.each(function() {
-				var obj = $(this),
-					ms = $(this).data('multiSelect');
+				var $obj = $(this),
+					ms = $obj.data('multiSelect');
 
 				// clean input if selectedLimit == 1
 				if (ms.options.selectedLimit == 1) {
 					for (var id in ms.values.selected) {
-						removeSelected(id, obj, ms.values, ms.options);
+						removeSelected(id, $obj, ms.values, ms.options);
 					}
 
-					cleanAvailable(item, ms.values);
+					cleanAvailable(items[0], ms.values);
 				}
-				addSelected(item, obj, ms.values, ms.options);
+
+				for (var i = 0, l = items.length; i < l; i++) {
+					addSelected(items[i], $obj, ms.values, ms.options);
+				}
+
+				$obj.trigger('change', ms);
 			});
 		},
 
@@ -139,14 +145,15 @@ jQuery(function($) {
 		 */
 		clean: function() {
 			return this.each(function() {
-				var obj = $(this);
-				var ms = $(this).data('multiSelect');
+				var $obj = $(this),
+					ms = $obj.data('multiSelect');
 
 				for (var id in ms.values.selected) {
-					removeSelected(id, obj, ms.values, ms.options);
+					removeSelected(id, $obj, ms.values, ms.options);
 				}
 
-				cleanAvailable(obj, ms.values);
+				cleanAvailable($obj, ms.values);
+				$obj.trigger('change', ms);
 			});
 		},
 
@@ -158,13 +165,13 @@ jQuery(function($) {
 		disable: function() {
 			return this.each(function() {
 				var $obj = $(this),
-					$wrapper = $obj.parent('.multiselect-wrapper'),
+					$wrapper = $obj.parent('.' + ZBX_STYLE_CLASS),
 					ms = $obj.data('multiSelect');
 
 				if (ms.options.disabled === false) {
 					$obj.attr('aria-disabled', true);
 					$('.multiselect-list', $obj).addClass('disabled');
-					$('.multiselect-button > button', $wrapper).attr('disabled', 'disabled');
+					$('.multiselect-button > button', $wrapper).prop('disabled', true);
 					$('input[type=text]', $wrapper).remove();
 					cleanAvailable($obj, ms.values);
 					$('.available', $wrapper).remove();
@@ -182,14 +189,14 @@ jQuery(function($) {
 		enable: function() {
 			return this.each(function() {
 				var $obj = $(this),
-					$wrapper = $obj.parent('.multiselect-wrapper'),
-					ms = $(this).data('multiSelect');
+					$wrapper = $obj.parent('.' + ZBX_STYLE_CLASS),
+					ms = $obj.data('multiSelect');
 
 				if (ms.options.disabled === true) {
 					var $input = makeMultiSelectInput($obj);
 					$obj.removeAttr('aria-disabled');
 					$('.multiselect-list', $obj).removeClass('disabled');
-					$('.multiselect-button > button', $wrapper).removeAttr('disabled');
+					$('.multiselect-button > button', $wrapper).prop('disabled', false);
 					$obj.append($input);
 					makeSuggsetionsBlock($obj);
 
@@ -240,6 +247,22 @@ jQuery(function($) {
 					}
 				}
 			});
+		},
+
+		/**
+		 * Return option value.
+		 *
+		 * @return string
+		 */
+		getOption: function(key) {
+			var ret = null;
+			this.each(function() {
+				if (typeof $(this).data('multiSelect') !== 'undefined') {
+					ret = $(this).data('multiSelect').options[key];
+				}
+			});
+
+			return ret;
 		}
 	};
 
@@ -265,7 +288,7 @@ jQuery(function($) {
 	 * @param string options['popup']['parameters']
 	 * @param int    options['popup']['width']
 	 * @param int    options['popup']['height']
-	 * @param string options['styles']				additional style for .multiselect-wrapper (optional)
+	 * @param string options['styles']				additional style for multiselect wrapper HTML element (optional)
 	 * @param string options['styles']['property']
 	 * @param string options['styles']['value']
 	 *
@@ -301,17 +324,21 @@ jQuery(function($) {
 		options = $.extend({}, defaults, options);
 
 		return this.each(function() {
-			var obj = $(this);
+			var $obj = $(this);
+
+			if (typeof $obj.data('multiSelect') !== 'undefined') {
+				return;
+			}
 
 			options = $.extend({}, {
-				required: (typeof obj.attr('aria-required') !== 'undefined') ? obj.attr('aria-required') : false
+				required: $obj.attr('aria-required') || false
 			}, options);
 
 			var ms = {
 				options: options,
 				values: {
 					search: '',
-					width: parseInt(obj.css('width')),
+					width: parseInt($obj.css('width')),
 					isWaiting: false,
 					isAjaxLoaded: true,
 					isMoreMatchesFound: false,
@@ -321,50 +348,50 @@ jQuery(function($) {
 				}
 			};
 
-			obj.removeAttr('aria-required');
+			$obj.removeAttr('aria-required');
 
 			// store the configuration in the elements data
-			obj.data('multiSelect', ms);
+			$obj.data('multiSelect', ms);
 
 			var values = ms.values;
 
 			// add wrap
-			obj.wrap(jQuery('<div>', {
-				'class': 'multiselect-wrapper',
+			$obj.wrap($('<div>', {
+				'class': ZBX_STYLE_CLASS,
 				css: options.styles
 			}));
 
 			// selected
-			var selected_div = $('<div>', {
+			var $selected_div = $('<div>', {
 				'class': 'selected'
 			});
-			var selected_ul = $('<ul>', {
+			var $selected_ul = $('<ul>', {
 				'class': 'multiselect-list'
 			});
 
-			obj.append(selected_div.append(selected_ul));
+			$obj.append($selected_div.append($selected_ul));
 
 			if (options.disabled) {
-				selected_ul.addClass('disabled');
+				$selected_ul.addClass('disabled');
 			}
 			else {
-				obj.append(makeMultiSelectInput(obj));
+				$obj.append(makeMultiSelectInput($obj));
 			}
 
 			// available
 			if (!options.disabled) {
-				makeSuggsetionsBlock(obj);
+				makeSuggsetionsBlock($obj);
 			}
 
 			// preload data
 			if (empty(options.data)) {
-				setDefaultValue(obj, options);
+				setDefaultValue($obj, options);
 			}
 			else {
-				loadSelected(options.data, obj, values, options);
+				loadSelected(options.data, $obj, values, options);
 			}
 
-			cleanLastSearch(obj);
+			cleanLastSearch($obj);
 
 			// draw popup link
 			if (options.popup.parameters != null) {
@@ -374,23 +401,23 @@ jQuery(function($) {
 					options.only_hostid = popup_options['only_hostid'];
 				}
 
-				var popupButton = $('<button>', {
+				var $popup_button = $('<button>', {
 					type: 'button',
 					'class': 'btn-grey',
 					text: options.labels['Select']
 				});
 
 				if (options.disabled) {
-					popupButton.attr('disabled', true);
+					$popup_button.prop('disabled', true);
 				}
 
-				popupButton.click(function(event) {
+				$popup_button.on('click', function(event) {
 					return PopUp('popup.generic', popup_options, null, event.target);
 				});
 
-				obj.parent().append($('<div>', {
+				$obj.parent().append($('<div>', {
 					'class': 'multiselect-button'
-				}).append(popupButton));
+				}).append($popup_button));
 			}
 		});
 	};
@@ -464,7 +491,7 @@ jQuery(function($) {
 							window.setTimeout(function() {
 								values.isWaiting = false;
 
-								var search = $input.val().replace(/^\s+/g, '');
+								var search = $input.val().replace(/^\s+|\s+$/g, '');
 
 								// re-check search after delay
 								if (search !== '' && $input.data('lastSearch') != search) {
@@ -480,7 +507,7 @@ jQuery(function($) {
 									var request_data = {
 										search: values.search,
 										limit: getLimit(values, options)
-									}
+									};
 
 									jqxhr = $.ajax({
 										url: options.url + '&curtime=' + new CDate().getTime(),
@@ -595,6 +622,7 @@ jQuery(function($) {
 										: ($selected.is(':last-child') ? $selected.prev() : $selected.next());
 
 									removeSelected(id, $obj, values, options);
+									$obj.trigger('change', ms);
 
 									if ($selected.length) {
 										var $collection = $('.selected li', $obj);
@@ -617,7 +645,8 @@ jQuery(function($) {
 								}
 							}
 							else if (e.which == KEY.BACKSPACE) {
-								/* Pressing Backspace on empty input field should select last element in
+								/*
+								 * Pressing Backspace on empty input field should select last element in
 								 * multiselect. For next Backspace press to be able to remove it.
 								 */
 								var $selected = $('.selected li:last-child', $obj).addClass('selected');
@@ -644,9 +673,9 @@ jQuery(function($) {
 		return $input;
 	}
 
-	function setDefaultValue(obj, options) {
+	function setDefaultValue($obj, options) {
 		if (!empty(options.defaultValue)) {
-			obj.append($('<input>', {
+			$obj.append($('<input>', {
 				type: 'hidden',
 				name: options.name,
 				value: options.defaultValue,
@@ -655,35 +684,37 @@ jQuery(function($) {
 		}
 	}
 
-	function removeDefaultValue(obj, options) {
+	function removeDefaultValue($obj, options) {
 		if (!empty(options.defaultValue)) {
-			$('input[data-default="1"]', obj).remove();
+			$('input[data-default="1"]', $obj).remove();
 		}
 	}
 
-	function loadSelected(data, obj, values, options) {
+	function loadSelected(data, $obj, values, options) {
 		$.each(data, function(i, item) {
-			addSelected(item, obj, values, options);
+			addSelected(item, $obj, values, options);
 		});
 	}
 
-	function loadAvailable(data, obj, values, options) {
-		cleanAvailable(obj, values);
+	function loadAvailable(data, $obj, values, options) {
+		cleanAvailable($obj, values);
 
 		// add new
 		if (options.addNew) {
 			var value = values['search'].replace(/^\s+|\s+$/g, '');
 
-			if (!empty(value)) {
+			if (value.length) {
 				var addNew = false;
 
-				if (!empty(data) || objectLength(values.selected) > 0) {
-					// check if value exist in availables
-					if (!empty(data)) {
-						var names = {};
+				if (data.length || objectLength(values.selected) > 0) {
+					var names = {};
 
+					// check if value exists among available
+					if (data.length) {
 						$.each(data, function(i, item) {
-							names[item.name.toUpperCase()] = true;
+							if (item.name === value) {
+								names[item.name.toUpperCase()] = true;
+							}
 						});
 
 						if (typeof names[value.toUpperCase()] === 'undefined') {
@@ -691,10 +722,8 @@ jQuery(function($) {
 						}
 					}
 
-					// check if value exist in selected
+					// check if value exists among selected
 					if (!addNew && objectLength(values.selected) > 0) {
-						var names = {};
-
 						$.each(values.selected, function(i, item) {
 							if (typeof item.isNew === 'undefined') {
 								names[item.name.toUpperCase()] = true;
@@ -716,7 +745,6 @@ jQuery(function($) {
 				if (addNew) {
 					data[data.length] = {
 						id: value,
-						prefix: '',
 						name: value + ' (' + options.labels['new'] + ')',
 						isNew: true
 					};
@@ -748,22 +776,22 @@ jQuery(function($) {
 				'class': 'multiselect-matches',
 				text: options.labels['No matches found']
 			})
-			.click(function() {
-				$('input[type="text"]', obj).focus();
+			.on('click', function() {
+				$('input[type="text"]', $obj).focus();
 			});
 
-			$('.available', obj).append(div);
+			$('.available', $obj).append(div);
 		}
 		else {
-			$('.available', obj)
+			$('.available', $obj)
 				.append($('<ul>', {
 					'class': 'multiselect-suggest',
 					'aria-hidden': true
 				}))
-				.mouseenter(function() {
+				.on('mouseenter', function() {
 					values.isAvailableOpened = true;
 				})
-				.mouseleave(function() {
+				.on('mouseleave', function() {
 					values.isAvailableOpened = false;
 				});
 
@@ -772,14 +800,14 @@ jQuery(function($) {
 					if (found == 0) {
 						preselected = (item.prefix || '') + item.name;
 					}
-					addAvailable(item, obj, values, options);
+					addAvailable(item, $obj, values, options);
 					found++;
 				}
 			});
 		}
 
 		if (found > 0) {
-			$('[aria-live]', obj).text(
+			$('[aria-live]', $obj).text(
 				(values.isMoreMatchesFound
 					? sprintf(t('More than %1$d matches for %2$s found'), found, values.search)
 					: sprintf(t('%1$d matches for %2$s found'), found, values.search)) +
@@ -787,7 +815,7 @@ jQuery(function($) {
 			);
 		}
 		else {
-			$('[aria-live]', obj).text(options.labels['No matches found']);
+			$('[aria-live]', $obj).text(options.labels['No matches found']);
 		}
 
 		// write more matches found label
@@ -796,26 +824,26 @@ jQuery(function($) {
 				'class': 'multiselect-matches',
 				text: options.labels['More matches found...']
 			})
-			.click(function() {
-				$('input[type="text"]', obj).focus();
+			.on('click', function() {
+				$('input[type="text"]', $obj).focus();
 			});
 
-			$('.available', obj).prepend(div);
+			$('.available', $obj).prepend(div);
 		}
 
-		showAvailable(obj, values);
+		showAvailable($obj, values);
 	}
 
-	function addSelected(item, obj, values, options) {
+	function addSelected(item, $obj, values, options) {
 		if (typeof values.selected[item.id] === 'undefined') {
-			removeDefaultValue(obj, options);
+			removeDefaultValue($obj, options);
 			values.selected[item.id] = item;
 
 			var prefix = (item.prefix || ''),
 				item_disabled = (typeof(item.disabled) !== 'undefined' && item.disabled);
 
 			// add hidden input
-			obj.append($('<input>', {
+			$obj.append($('<input>', {
 				type: 'hidden',
 				name: (options.addNew && item.isNew) ? options.name + '[new]' : options.name,
 				value: item.id,
@@ -838,7 +866,8 @@ jQuery(function($) {
 						.addClass('subfilter-disable-btn')
 						.on('click', function() {
 							if (!options.disabled && !item_disabled) {
-								removeSelected(item.id, obj, values, options);
+								removeSelected(item.id, $obj, values, options);
+								$obj.trigger('change', $obj.data('multiSelect'));
 							}
 						}))
 			);
@@ -851,113 +880,97 @@ jQuery(function($) {
 				li.addClass('disabled');
 			}
 
-			$('.selected ul', obj).append(li);
+			$('.selected ul', $obj).append(li);
 
-			resizeSelectedText(li, obj);
+			resizeSelectedText(li, $obj);
 
 			// set readonly
-			if (options.selectedLimit != 0 && $('.selected li', obj).length >= options.selectedLimit) {
-				setSearchFieldVisibility(false, obj, options);
+			if (options.selectedLimit != 0 && $('.selected li', $obj).length >= options.selectedLimit) {
+				setSearchFieldVisibility(false, $obj, options);
 			}
 		}
 	}
 
-	function removeSelected(id, obj, values, options) {
+	function removeSelected(id, $obj, values, options) {
 		// remove
-		$('.selected li[data-id="' + id + '"]', obj).remove();
-		$('input[value="' + id + '"]', obj).remove();
+		$('.selected li[data-id]', $obj).each(function(){
+			if ($(this).data('id') == id) {
+				$(this).remove();
+			}
+		});
+		$('input', $obj).each(function(){
+			if ($(this).val() == id) {
+				$(this).remove();
+			}
+		});
 
 		delete values.selected[id];
 
 		// remove readonly
-		if ($('.selected li', obj).length == 0) {
-			setDefaultValue(obj, options);
+		if ($('.selected li', $obj).length == 0) {
+			setDefaultValue($obj, options);
 		}
 
 		// clean
-		cleanAvailable(obj, values);
-		cleanLastSearch(obj);
+		cleanAvailable($obj, values);
+		cleanLastSearch($obj);
 
-		if (options.selectedLimit == 0 || $('.selected li', obj).length < options.selectedLimit) {
-			setSearchFieldVisibility(true, obj, options);
-			$('input[type="text"]', obj).focus();
+		if (options.selectedLimit == 0 || $('.selected li', $obj).length < options.selectedLimit) {
+			setSearchFieldVisibility(true, $obj, options);
+			$('input[type="text"]', $obj).focus();
 		}
 	}
 
-	function addAvailable(item, obj, values, options) {
-		var li = $('<li>', {
-			'data-id': item.id,
-			'data-label': (item.prefix || '') + item.name
-		})
-		.click(function() {
-			select(item.id, obj, values, options);
-		})
-		.hover(function() {
-			$('.available li.suggest-hover', obj).removeClass('suggest-hover');
-			li.addClass('suggest-hover');
-		});
+	function addAvailable(item, $obj, values, options) {
+		var is_new = item.isNew || false,
+			prefix = item.prefix || '',
+			search = values.search.replace(/[.+?^${}()|[\]\\]/g, '\\$&').replace(/[*]/g, '\\\*?'),
+			$li = $('<li>', {
+				'data-id': item.id,
+				'data-label': prefix + item.name
+			})
+			.on('click', function() {
+				select(item.id, $obj, values, options);
+			})
+			.on('mouseenter', function() {
+				$('.available li.suggest-hover', $obj).removeClass('suggest-hover');
+				$li.addClass('suggest-hover');
+			});
 
-		if (!empty(item.prefix)) {
-			li.append($('<span>', {
-				'class': 'grey',
-				text: item.prefix
-			}));
+		if (prefix !== '') {
+			$li.append($('<span>', {'class': 'grey', text: prefix}));
 		}
 
 		// highlight matched
-		var text = item.name.toLowerCase(),
-			search = values.search.toLowerCase(),
-			is_new = item.isNew || false,
-			start = 0,
-			end = 0;
+		$li.append(item.name.replace(new RegExp(search, "gi"), function(match) {
+			return '<span' + (!is_new ? ' class="suggest-found"' : '') + '>' + match + '</span>';
+		})).toggleClass('suggest-new', is_new);
 
-		while (text.indexOf(search, end) > -1) {
-			end = text.indexOf(search, end);
-
-			if (end > start) {
-				li.append($('<span>', {
-					text: item.name.substring(start, end)
-				}));
-			}
-
-			li.append($('<span>', {
-				'class': !is_new ? 'suggest-found' : null,
-				text: item.name.substring(end, end + search.length)
-			})).toggleClass('suggest-new', is_new);
-
-			end += search.length;
-			start = end;
-		}
-
-		if (end < item.name.length) {
-			li.append($('<span>', {
-				text: item.name.substring(end, item.name.length)
-			}));
-		}
-
-		$('.available ul', obj).append(li);
+		$('.available ul', $obj).append($li);
 	}
 
-	function select(id, obj, values, options) {
+	function select(id, $obj, values, options) {
 		if (values.isAjaxLoaded && !values.isWaiting) {
-			addSelected(values.available[id], obj, values, options);
+			addSelected(values.available[id], $obj, values, options);
 
-			hideAvailable(obj);
-			cleanAvailable(obj, values);
-			cleanLastSearch(obj);
+			hideAvailable($obj);
+			cleanAvailable($obj, values);
+			cleanLastSearch($obj);
 
-			if (options.selectedLimit == 0 || $('.selected li', obj).length < options.selectedLimit) {
-				$('input[type="text"]', obj).focus();
+			if (options.selectedLimit == 0 || $('.selected li', $obj).length < options.selectedLimit) {
+				$('input[type="text"]', $obj).focus();
 			}
+
+			$obj.trigger('change', $obj.data('multiSelect'));
 		}
 	}
 
-	function showAvailable(obj, values) {
-		var available = $('.available', obj),
+	function showAvailable($obj, values) {
+		var available = $('.available', $obj),
 			available_paddings = available.outerWidth() - available.width();
 
 		available.css({
-			'width': obj.outerWidth() - available_paddings,
+			'width': $obj.outerWidth() - available_paddings,
 			'left': -1
 		});
 
@@ -966,8 +979,8 @@ jQuery(function($) {
 
 		if (objectLength(values.available) != 0) {
 			// remove selected item selected state
-			if ($('.selected li.selected', obj).length > 0) {
-				$('.selected li.selected', obj).removeClass('selected');
+			if ($('.selected li.selected', $obj).length > 0) {
+				$('.selected li.selected', $obj).removeClass('selected');
 			}
 
 			// pre-select first available
@@ -980,30 +993,30 @@ jQuery(function($) {
 		}
 	}
 
-	function hideAvailable(obj) {
-		$('.available', obj).fadeOut(0);
+	function hideAvailable($obj) {
+		$('.available', $obj).fadeOut(0);
 	}
 
-	function cleanAvailable(obj, values) {
-		$('.multiselect-matches', obj).remove();
-		$('.available ul', obj).remove();
+	function cleanAvailable($obj, values) {
+		$('.multiselect-matches', $obj).remove();
+		$('.available ul', $obj).remove();
 		values.available = {};
 		values.isMoreMatchesFound = false;
 	}
 
-	function cleanLastSearch(obj) {
-		$('input[type="text"]', obj).data('lastSearch', '').val('');
+	function cleanLastSearch($obj) {
+		$('input[type="text"]', $obj).data('lastSearch', '').val('');
 	}
 
-	function cleanSearchInput(obj) {
-		$('input[type="text"]', obj).val('');
+	function cleanSearchInput($obj) {
+		$('input[type="text"]', $obj).val('');
 	}
 
-	function resizeSelectedText(li, obj) {
+	function resizeSelectedText(li, $obj) {
 		var	li_margins = li.outerWidth(true) - li.width(),
 			span = $('span.subfilter-enabled', li),
 			span_paddings = span.outerWidth(true) - span.width(),
-			max_width = $('.selected ul', obj).width() - li_margins - span_paddings,
+			max_width = $('.selected ul', $obj).width() - li_margins - span_paddings,
 			text = $('span:first-child', span);
 
 		if (text.width() > max_width) {
@@ -1016,8 +1029,8 @@ jQuery(function($) {
 		}
 	}
 
-	function resizeAllSelectedTexts(obj, options, values) {
-		$('.selected li', obj).each(function() {
+	function resizeAllSelectedTexts($obj, options, values) {
+		$('.selected li', $obj).each(function() {
 			var li = $(this),
 				id = li.data('id'),
 				span = $('span.subfilter-enabled', li),
@@ -1029,24 +1042,24 @@ jQuery(function($) {
 			// rewrite previous text to original
 			text.text(t);
 
-			resizeSelectedText(li, obj);
+			resizeSelectedText(li, $obj);
 		});
 	}
 
-	function scrollAvailable(obj) {
-		var	selected = $('.available li.suggest-hover', obj),
-			available = $('.available', obj);
+	function scrollAvailable($obj) {
+		var	selected = $('.available li.suggest-hover', $obj),
+			available = $('.available', $obj);
 
 		if (selected.length > 0) {
 			var	available_height = available.height(),
 				selected_top = 0,
 				selected_height = selected.outerHeight(true);
 
-			if ($('.multiselect-matches', obj)) {
-				selected_top += $('.multiselect-matches', obj).outerHeight(true);
+			if ($('.multiselect-matches', $obj)) {
+				selected_top += $('.multiselect-matches', $obj).outerHeight(true);
 			}
 
-			$('.available li', obj).each(function() {
+			$('.available li', $obj).each(function() {
 				var item = $(this);
 				if (item.hasClass('suggest-hover')) {
 					return false;
